DHCPKit VPP
===========

This DHCPKit extension allows DHCPKit to be used as the DHCPv6 server of a Vector Packet Processing (VPP) router. See
https://fd.io/technology and https://wiki.fd.io/view/VPP for more information on VPP.


Distribution status
-------------------

.. image:: https://img.shields.io/pypi/v/dhcpkit_vpp.svg
  :target: https://pypi.python.org/pypi/dhcpkit_vpp

.. image:: https://img.shields.io/pypi/status/dhcpkit_vpp.svg
  :target: https://pypi.python.org/pypi/dhcpkit_vpp

.. image:: https://img.shields.io/pypi/l/dhcpkit_vpp.svg
  :target: https://pypi.python.org/pypi/dhcpkit_vpp

.. image:: https://img.shields.io/pypi/pyversions/dhcpkit_vpp.svg
  :target: https://pypi.python.org/pypi/dhcpkit_vpp

.. image:: https://img.shields.io/pypi/dw/dhcpkit_vpp.svg
  :target: https://pypi.python.org/pypi/dhcpkit_vpp
